@@ -2,9 +2,9 @@ INSERT INTO version (table_name, table_version) values ('dialog','10');
 CREATE TABLE dialog (
     dlg_id BIGINT PRIMARY KEY NOT NULL,
     callid VARCHAR(255) NOT NULL,
-    from_uri VARCHAR(128) NOT NULL,
+    from_uri VARCHAR(255) NOT NULL,
     from_tag VARCHAR(64) NOT NULL,
-    to_uri VARCHAR(128) NOT NULL,
+    to_uri VARCHAR(255) NOT NULL,
     to_tag VARCHAR(64) NOT NULL,
     mangled_from_uri VARCHAR(64) DEFAULT NULL,
     mangled_to_uri VARCHAR(64) DEFAULT NULL,
@@ -14,8 +14,8 @@ CREATE TABLE dialog (
     callee_ping_cseq INTEGER NOT NULL,
     caller_route_set TEXT,
     callee_route_set TEXT,
-    caller_contact VARCHAR(128) NOT NULL,
-    callee_contact VARCHAR(128) NOT NULL,
+    caller_contact VARCHAR(255),
+    callee_contact VARCHAR(255),
     caller_sock VARCHAR(64) NOT NULL,
     callee_sock VARCHAR(64) NOT NULL,
     state INTEGER NOT NULL,
